# -*- coding: utf-8 -*-

from __future__ import division

from django_query import get_query_value
from django_response import response
from paginator import pagination

from api.wx_views import get_course_field_limit_scene_qrcode_url
from registration.models import CourseRegisterFieldInfo, CourseRegisterFieldPoolInfo


def get_course_field_default(request):
    fields = CourseRegisterFieldPoolInfo.objects.filter(status=True)
    fields = [f.data for f in fields]

    return response(data={
        'fields': fields,
    })


def add_course_field(request):
    course_id = request.POST.get('course_id', '')
    course_name = request.POST.get('course_name', '')
    fields = get_query_value(request, 'fields', val_cast_type='listjson')

    course_field = CourseRegisterFieldInfo.objects.create(course_id=course_id, course_name=course_name, fields=fields)
    course_field.limit_scene_qrcode_url = get_course_field_limit_scene_qrcode_url(course_field.field_id)
    course_field.save()

    return response(data={
        'field_id': course_field.field_id,
    })


def update_course_field(request):
    field_id = request.POST.get('field_id', '')
    course_id = request.POST.get('course_id', '')
    course_name = request.POST.get('course_name', '')
    fields = get_query_value(request, 'fields', val_cast_type='listjson')

    CourseRegisterFieldInfo.objects.filter(field_id=field_id).update(course_id=course_id, course_name=course_name, fields=fields)

    return response()


def get_course_field(request):
    admin_id = request.POST.get('admin_id', '')
    field_id = request.POST.get('field_id', '')

    try:
        field = CourseRegisterFieldInfo.objects.get(field_id=field_id)
    except CourseRegisterFieldInfo.DoesNotExist:
        return response()

    return response(data={
        'field': field.qrcodedata(admin_id),
    })


def get_course_field_list(request):
    admin_id = request.POST.get('admin_id', '')
    page = request.POST.get('page', 1)
    num = request.POST.get('num', 20)

    fields = CourseRegisterFieldInfo.objects.filter(status=True)
    count = fields.count()
    fields, left = pagination(fields, page, num)
    fields = [f.qrcodedata(admin_id) for f in fields]

    return response(data={
        'fields': fields,
        'count': count,
        'left': left,
    })


def delete_course_field(request):
    field_id = request.POST.get('field_id', '')

    CourseRegisterFieldInfo.objects.filter(field_id=field_id).update(statue=False)

    return response()
